#
# spec file for package python-iminuit
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# Python2 support dropped since version 1.4.0
%define skip_python2 1
%define skip_python36 1
%define modname iminuit
Name:           python-%{modname}
Version:        2.12.1
Release:        1.1
Summary:        Python bindings for MINUIT2
License:        MIT
URL:            https://github.com/scikit-hep/iminuit
Source0:        https://files.pythonhosted.org/packages/source/i/iminuit/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy >= 1.11.3}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pybind11 >= 2.9.0}
BuildRequires:  %{python_module pybind11-devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  cmake >= 3.13
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.11.3
Recommends:     python-matplotlib
Recommends:     python-scipy
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# Fix unresolved status for Leap 15.x on account of multiple choices for python3-importlib-metadata (python3-importlib-metadata and python3-importlib_metadata)
BuildRequires:  %{python_module importlib-metadata}
# /SECTION
%python_subpackages

%description
iminuit is a Python interface to the MINUIT2 C++ package.

It can be used as a general function minimization method,
but is most commonly used for likelihood fits of models to data,
and to get model parameter error estimates from likelihood profile analysis.

%prep
%setup -q -n %{modname}-%{version}
# We use external pybind11, just to be sure remove bundled pybind11 entirely
rm -fr extern/pybind11

%build
export CFLAGS="%{optflags}"
export CMAKE_ARGS="-DIMINUIT_EXTERNAL_PYBIND11=ON"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/%{modname}/
%{python_sitearch}/%{modname}-%{version}-py%{python_version}.egg-info/

%changelog
* Mon Jul  4 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.12.1:
  * cost.BarlowBeestonLite: method “hpd” has been modified to fix
    performance in cases where bins are not dominated by a single
    template.
* Wed Jun 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.12.0:
  * New
  - New cost function cost.BarlowBeestonLite for template fits
    with templates obtained from simulation or sWeighted data
  - Formerly private chi2 utility cost functions
    (cost.poisson_chi2, etc.), are now part of public API
  - Support custom grid in Minuit.profile, iminuit.mncontour,
    iminuit.contour
  - Handle common CL values in Minuit.mnprofile and
    Minuit.mncontour without scipy
  * Fixes
  - Skip tests that use np.float128 on platforms where this type
    is not supported
  - Minuit.valid now returns False if EDM is NaN
  - subtract_min setting is no longer ignored by
    Minuit.draw_contour
  * Documentation: New study about template fits
  * Minuit no longer warns when a function is used that has no
    errordef attribute and Minuit.errordef is not explicitly set.
    The function is assumed to be chi-square-like up to an
    arbitrary constant, unless errordef is explicitly set to
    something else.
  * More type correctness in API, better hiding of private objects
    in library
  * Add option to use external pybind11
- Pass cmake option to build against external pybind11; add
  BuildRequires: python-pybind11 and python-pybind11-devel and
  remove bundled pybind11 from source dir.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.11.2:
  * Fixed wording in cost function tutorial
- Changes from version 2.11.1:
  * Fixed a failure of util.make_with_signature in some
    situations.
  * Raise numpy.VisibleDeprecationWarning instead of
    warnings.DeprecationWarning.
  * util.propagate is deprecated in favour of jacobi.propagate
    from the jacobi library.
- Changes from version 2.11.0:
  * All builtin cost functions now support multidimensional data
  * Matrix.to_dict was added for symmetry with
    BasicValueView.to_dict
  * For long-running fits, total runtime is now shown in FMin
    display and total runtime can be accessed via property
    FMin.time
  * In binned fits when ndof is zero, show reduced chi2 = nan in
    the FMin display instead of raising a ZeroDivisionError
  * Tutorials and studies are now listed separately
  * Tutorial for fits of multivariate data were added
  * The cost function tutorial was improved
  * Studies in regard to performance were added, including a
    comparison with RooFit
* Sat Mar  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.10.0:
  * Minuit.draw_mncontour now works with matplotlib >= 3.5.
  * Builtin cost functions now work correctly when the mask is set
    and data is updated on the existing cost function.
  * Builtin cost functions are now more performant when used with
    weighted binned data.
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.9.0:
  * Minuit.draw_mncontour now works with matplotlib >= 3.5.
  * Builtin cost functions now work correctly when the mask is set
    and data is updated on the existing cost function.
  * Builtin cost functions are now more performant when used with
    weighted binned data.
* Wed Dec  8 2021 pgajdos@suse.com
- version update to 2.8.4
  Fixes
  * Pickling of util.Matrix resulted in incomplete state after unpickling,
    which would cause an exception when you tried to print the matrix
  Documentation
  * New tutorial on fitting PDFs that depend on a conditional variable
  * Fixed JAX tutorial, adapting to change in their interface
  * Extended documentation of cost functions
* Thu Sep 16 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.3:
  * util.propagate now discriminates between diverging derivates
    (using the value NaN for the derivate) and non-converging
    derivatives (using the best value computed so far for the
    derivative).
  * Update documentation.
- Changes from version 2.8.2:
  * Minuit.draw_mncontour can now be used by passing a single
    float to keyword cl, in addition to passing a list of floats.
  * Use pybind11::ssize_t everywhere instead of non-standard
    ssize_t to fix compilation against Python-3.10 on Windows.
  * Update documentation.
* Mon Aug  9 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.1:
  * Undocumented changes.
* Wed Jul 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.0:
  * Minor API change: Minuit.mncontour now raises RuntimeError
    instead of ValueError if it is not called at a valid minimum
    point.
  * New features: Minuit.mncontour can now be called at any point
    without running a minimiser before, similar to Minuit.minos.
  * Fixes: Minuit.mncontour used to fail if called twice in a row.
* Thu Jun 17 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.6.1:
  * Calling Minuit.fixed[...] = False on parameter that was not
    fixed before lead to undefined behaviour in Minuit2 C++ code
    (patch submitted to ROOT).
  * Upgrade Minuit2 C++ code to latest ROOT master with simplified
    internal class structure and class tags replaced with enums.
* Wed May  5 2021 Atri Bhattacharya <badshah400@gmai.com>
- Update to version 2.6.0:
  * Builtin cost functions now report the number of data points
    with the attribute Cost.ndata.
  * New attribute Minuit.ndof returns the degrees of freedom if
    the cost function reports it or NaN.
  * New attribute FMin.reduced_chi2 to report the reduced chi2 of
    the fit; returns NaN if the reduced chi2 cannot be computed
    for the cost function, in case of unbinned maximum-likelihood
    or when the attribute Cost.ndata is missing.
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Mon Feb 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.0:
  * New features:
  - iminuit.minimize: Keyword method now accepts "migrad" and
    "simplex".
  - iminuit.minimize: Keyword option now supports keyword "stra"
    to set Minuit.strategy.
  - iminuit.minimize: OptimizeResult.message now states if
    errors are not reliable.
  * Minuit now supports functions wrapped with functools.partial.
  * Upgrade Minuit2 C++ code in ROOT to latest master with
    following improvements:
  - improvement of seed when using an analytical gradient.
  - fix of last minimum state added twice to vector of minimum
    states in some cases (saves a bit of memory).
  * Documentation improvements.
  * Updated tutorial about automatic differentiation, added
    comparison of numba.njit and jax.jit.
- Changes from version 2.3.0:
  * New features: iminuit.cost.BinnedNLL and
    iminuit.cost.ExtendedBinnedNLL now support weighted binned
    data.
  * Bug-fixes: FMin.edm_goal now remains unchanged if Minuit.hesse
    is run after Minuit.migrad.
  * Other: Update to cibuildwheels-1.8.0 and workflow
    simplification.
* Mon Dec 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.1:
  * New features
  - Minuit.profile, Minuit.mnprofile, Minuit.contour,
    Minuit.draw_profile, Minuit.draw_mnprofile, and
    Minuit.draw_contour can now be called with subtract_min=True
    even if Minuit.fmin is None.
  - iminuit.__version__ now also displays the ROOT version of
    the C++ Minuit2 library.
  - Support for adding constant numbers to cost functions, this
    allows you to write sum(cost1, cost2, ...) and may be useful
    to subtract a constant bias from the cost.
  * Other
  - Documentation improvements - Further transition to numpydoc.
  - Clarified that iminuit is based on ROOT code - List full
    iminuit version including ROOT version in docs.
  - Added type hints to many interfaces (incomplete).
  - Renamed iminuit._minuit to iminuit.minuit, making the module
    public.
  - Renamed iminuit._minimize to iminuit.minimize, making the
    module public.
  - pydocstyle added to pre-commit checks.
* Mon Dec 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.0:
  * New features:
  - Cost functions in iminuit.cost are now additive, creating a
    new cost function with the union of parameters that returns
    the sum of the results of the individual cost functions.
  - iminuit.cost.NormalConstraint was added as a means to add
    soft constraints on a parameter, can also be used to set up
    a covariance matrix between several parameters.
  * Other: Documentation improvements, started transition to numpydoc
- Drop _service file and tests.tar.xz source, since tests are now
  included in the iminuit source tarball.
* Sat Dec 12 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.0:
  * Long list of changes, see
    <https://iminuit.readthedocs.io/en/stable/changelog.html#december-7-2020>.
- Add _service file to download tests from github directly as they
  are not included in the pypi tarball any more
  (gh#scikit-hep/iminuit#572).
- New BuildRequires: cmake >= 3.13.
* Sun Nov 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.4:
    Fixed broken sdist package in 1.5.3
- Changes from version 1.5.3:
  * Fixed a crash when throw_nan=True is used and the throw is
    triggered.
  * Add python_requires (gh#scikit-hep/iminuit#496) by @henryiii.
  * Fixed buggy display of text matrix if npar != 2
    (gh#scikit-hep/iminuit#493).
  * Switch extern Minuit2 repo to official root repo
    (gh#scikit-hep/iminuit#500), ROOT state: a5d880a434.
  * Add ngrad and ngrad_total to FMin display, rename ncalls to
    nfcn_total (gh#scikit-hep/iminuit#489).
  * Use __getattr__ to hide deprecated interface from Python
    help() (gh#scikit-hep/iminuit#491).
  * Improvements to tutorials by @giammi56.
  * Show number of gradient calls in FMin display (if nonzero)
    instead of errordef value.
  * Deprecated:
  - Minuit.ncalls, use Minuit.nfcn instead
  - Minuit.ngrads, use Minuit.ngrad instead
* Sat Oct 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.2:
  - Fixed regression of the convergence rate of Minuit.migrad for
    low precision cost functions by restoring a heuristic that
    calls Migrad several times if convergence is not reached on
    first try; made this heuristic configurable with iterate
    keyword.
  - Clarify in FMin display how the EDM convergence criterion uses
    the EDM goal.
- Changes from version 1.5.1:
  - Fixed mistake in “parameter at limit” warning, which did not
    report correctly if parameter was at the upper limit.
- Changes from version 1.5.0:
  * New features
  - New more compact function minimum display with warning about
    parameters at limit.
  - Colours adjusted in HTML display to enhance contrast for
    people with color blindness.
  - Allow subclasses to use Minuit.from_array_func
    (gh#scikit-hep/iminuit#467).
  - Nicer tables on terminal thanks to unicode characters.
  - Wrapped functions’ parameters are now recognised by iminuit.
  - Dark theme friendlier HTML style
    (gh#scikit-hep/iminuit#481).
  * Bug-Fixes
  - Fixed reported EDM goal for really small tolerances.
  - Minuit.np_merrors now works correctly when some parameters
    are fixed.
  - Fixed HTML display of Minuit.matrix when some diagonal
    elements are zero.
  * Deprecated
  - Removed nsplit option from Minuit.migrad
    (gh#scikit-hep/iminuit#462).
* Wed Aug  5 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.4.9:
  * Fixes an error introduced in 1.4.8 in Minuit.minos when var
    keyword is used and at least one parameter is fixed.
- Changes from versions 1.3.9 through 1.4.8: See
  https://iminuit.readthedocs.io/en/stable/changelog.html.
- Drop python2 builds: no longer supported upstream.
- Drop python-pytestrunner BuildRequires for test in favour of
  python-pytest.
- Fix unresolved status for Leap 15.x on account of multiple
  choices for python3-importlib-metadata
  (python3-importlib-metadata and python3-importlib_metadata).
- Simplify %%check section by dropping directory renaming (no
  longer seems to be needed).
* Wed Nov 20 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.3.8
  * fixed internal plotting when Minuit.from_array_func is used
  * documentation updates
  * reproduceable build
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions.
* Mon Aug 19 2019 Atri Bhattacharya <badshah400@gmail.com>
- Initial version.
